@@ -106,7 +106,7 @@ def alignment_sh_dc(fastq_map, ref_name, ref_seq, ref_path, sam_path, sh_output,
     return fastq_map, all_job_id
 
 
-def mut_count_sh_bc(sample_name, cmd, mt, sh_output_dir,logger, cores):
+def mut_count_sh_bc(sample_name, cmd, mt, mm, sh_output_dir, logger, cores):
     """
     Submit mutation count jobs to BC
 
@@ -119,7 +119,7 @@ def mut_count_sh_bc(sample_name, cmd, mt, sh_output_dir,logger, cores):
         sh.write(cmd+"\n")
         os.system(f"chmod 755 {shfile}")
     # submit this to the cluster
-    sub_cmd = ["submitjob2","-w", str(mt), "-c", f"{cores}", "-m", "35", shfile, "&>>", log_f]
+    sub_cmd = ["submitjob2","-w", str(mt), "-c", f"{cores}", "-m", f"{mm}", shfile, "&>>", log_f]
     logger.debug(sub_cmd)
     job = subprocess.run(sub_cmd, stdout=subprocess.PIPE)
     job_id = job.stdout.decode("utf-8").strip().split(".")[0]
@@ -128,7 +128,7 @@ def mut_count_sh_bc(sample_name, cmd, mt, sh_output_dir,logger, cores):
     return job_id
 
 
-def mut_count_sh_dc(sample_name, cmd, mt, sh_output_dir, logger, cores):
+def mut_count_sh_dc(sample_name, cmd, mt, mm, sh_output_dir, logger, cores):
     """
     Submit mutation count jobs to DC
     """
@@ -141,7 +141,7 @@ def mut_count_sh_dc(sample_name, cmd, mt, sh_output_dir, logger, cores):
         os.system(f"chmod 755 {shfile}")
     #sample_error_file = os.path.join(log_dir, f"sample_{sample_name}.log")
     # submit this to the cluster
-    sub_cmd = ["submitjob", "-w", str(mt), "-c", f"{cores}", "-m", "35", shfile, "&>>", log_f]
+    sub_cmd = ["submitjob", "-w", str(mt), "-c", f"{cores}", "-m", f"{mm}", shfile, "&>>", log_f]
     logger.debug(sub_cmd)
     job = subprocess.run(sub_cmd, stdout=subprocess.PIPE)
     job_id = job.stdout.decode("utf-8").strip()
